@@ -100,11 +100,11 @@ class AzuremlLogger(object):
             workspace=self.run.experiment.workspace,
             model_name=postagging_registry,
             model_path=training_mount_folder,
-            child_paths=['model.pkl'],
+            child_paths=['model.pkl', 'model.py'],
             description='POS Tagging Pytorch Model',
             model_framework=Model.Framework.PYTORCH,  
             model_framework_version=self.torch_version, 
-            tags={'pkl': 'teste'}
+            tags = {'pkl': 'teste'}
         )
         self.run.log(postagging_registry, postagging_model)
 
@@ -113,7 +113,7 @@ class AzuremlLogger(object):
             workspace=self.run.experiment.workspace,
             model_name=postagging_registry_label,
             model_path=training_mount_folder,
-            child_paths=['vocab-label.pkl'],
+            child_paths=['vocab-label.pkl', 'vocab.py'],
             description='POS Tagging Pytorch Labels',
             tags={'pkl': 'teste'}
         )
